@@ -2,8 +2,7 @@ opendir <- function(dir) {
   osType <- Sys.info()[['sysname']]
   if (osType == "Windows") {
     tryCatch(shell.exec(dir), error = function(e) {NULL})
-  }
-  if (osType == "Linux") {
+  } else {
     tryCatch(system(paste(Sys.getenv("R_BROWSER"), dir), ignore.stderr = TRUE), error = function(e) {NULL})
   }
 }
