@@ -1,18 +1,53 @@
 plot_mz_eic <- function(filelist, filelocation, mzTarget, massAccuracy, number_processing_threads = 1, rtstart = 0, rtend = 0, plotTitle = "") {
   ##
-  clust <- makeCluster(number_processing_threads)
-  registerDoParallel(clust)
-  ##
-  dflist <- foreach(i = filelist) %dopar% {
+  call_plot_mz_eic <- function(i) {
     p2l <- IDSL.MXP::peak2list(filelocation, i)
     scanTable <- p2l[["scanTable"]]
     spectraList <- p2l[["spectraList"]]
     mzdf <- do.call(rbind, lapply(1:length(spectraList),function(l) { cbind(spectraList[[l]],scanTable$retentionTime[l],l) }))
     df <- data.frame(RT = as.numeric(mzdf[, 3]), Intensity = as.numeric(mzdf[, 2]), mz = as.numeric(mzdf[, 1]), scan = as.numeric(mzdf[, 4]))
-    df <- df[which(df$mz < mzTarget + massAccuracy & df$mz > mzTarget - massAccuracy),]
-    df
+    df <- df[which(df$mz < mzTarget + massAccuracy & df$mz > mzTarget - massAccuracy), ]
+    return(df)
   }
-  stopCluster(clust)
+  ##
+  ##############################################################################
+  ##
+  if (number_processing_threads == 1) {
+    ##
+    dflist <- lapply(filelist, function(i) {
+      call_plot_mz_eic(i)
+    })
+    ##
+  } else {
+    osType <- Sys.info()[['sysname']]
+    ##
+    ############################################################################
+    ##
+    if (osType == "Windows") {
+      ##
+      clust <- makeCluster(number_processing_threads)
+      clusterExport(clust, setdiff(ls(), c("clust", "filelist")), envir = environment())
+      ##
+      dflist <- parLapply(clust, filelist, function(i) {
+        call_plot_mz_eic(i)
+      })
+      ##
+      stopCluster(clust)
+      ##
+      ##########################################################################
+      ##
+    } else {
+      ##
+      dflist <- mclapply(filelist, function(i) {
+        call_plot_mz_eic(i)
+      }, mc.cores = number_processing_threads)
+      ##
+      closeAllConnections()
+      ##
+    }
+  }
+  ##
+  ##############################################################################
   ##
   inten.maxvec <- sapply(1:length(dflist), function(x){max(dflist[[x]][, 2])})
   inten.minvec <- sapply(1:length(dflist), function(x){min(dflist[[x]][, 2])})
@@ -22,7 +57,7 @@ plot_mz_eic <- function(filelist, filelocation, mzTarget, massAccuracy, number_p
   ##
   rtmax <- max(rt.maxvec)
   rtmin <- min(rt.minvec)
-  if (rtstart != 0 & rtend != 0) {
+  if ((rtstart != 0) & (rtend != 0)) {
     rtmax = rtend
     rtmin = rtstart
   }
